@@ -117,8 +117,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     }
@@ -164,8 +163,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -173,8 +171,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -182,8 +179,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -191,8 +187,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -200,8 +195,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -209,8 +203,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -218,8 +211,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -227,8 +219,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -236,8 +227,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -245,8 +235,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -254,20 +243,18 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
                     "oob_ip": {
-                        "type": "ip"
+                        "type": "text"
                     },
                     "os": {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -275,8 +262,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -284,8 +270,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -293,8 +278,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -302,8 +286,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -311,8 +294,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -320,8 +302,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -329,8 +310,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -338,8 +318,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -347,8 +326,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     },
@@ -356,8 +334,7 @@ body = {
                         "type": "text",
                         "fields": {
                             "keyword": {
-                                "type": "keyword",
-                                "ignore_above": 256
+                                "type": "keyword"
                             }
                         }
                     }
@@ -488,8 +465,6 @@ def get_hosts(zapi, es, tpl_name):
     dt = time.strftime('%Y.%m.%d', time.localtime())
     for host in hosts:
         host['@timestamp'] = datetime.utcfromtimestamp(time.time())
-        host['group_names'] = [group['name'] for group in host['groups']]
-        host['ipv4_addresses'] = [aif['ip'] for aif in host['interfaces']]
         body_datas.append({
             '_id': host['hostid'],
             '主机名称': host['inventory'].get('name', host['host']),
@@ -532,8 +507,8 @@ def get_hosts(zapi, es, tpl_name):
 
     for host in hosts:
         host['_id'] = host['hostid']
-    helpers.bulk(es, hosts, index='zabbix-raw-host-info-' + dt, raise_on_error=False)
-    helpers.bulk(es, body_datas, index='zabbix-host-info-' + dt, raise_on_error=False)
+    helpers.bulk(es, hosts, index='zabbix-raw-host-info-' + dt, raise_on_error=True)
+    helpers.bulk(es, body_datas, index='zabbix-host-info-' + dt, raise_on_error=True)
 
 
 def main(args):
